<header>
<p align="center">
    <img src=".github/images/starling_bearing_logo.png" width="20%" height="20%" alt="Starling Bearing Logo">
</p>
<h1 align='center' style='border-bottom: none;'>Starling Bearing</h1>
<h3 align='center'>Spatial Python Framework</h3>
</header>

<br/>

<div align="center">
  <a href="https://github.com/starling-cloud/bearing/issues/new?assignees=&labels=Needs%3A+Triage+%3Amag%3A%2Ctype%3Abug-suspected&template=bug_report.yml">Report a Bug</a>
  |
  <a href="https://github.com/starling-cloud/bearing/issues/new?assignees=&labels=Needs%3A+Triage+%3Amag%3A%2Ctype%3Afeature-request%2CHelp+wanted+%F0%9F%AA%A7&template=feature_request.yml">Request a Feature</a>
  |
  <a href="https://github.com/starling-cloud/bearing/issues/new?assignees=&labels=Needs%3A+Triage+%3Amag%3A%2Ctype%3Aquestion&template=question.yml">Ask a Question</a>
  |
  <a href="https://github.com/starling-cloud/bearing/issues/new?assignees=&labels=Needs%3A+Triage+%3Amag%3A%2Ctype%3Aenhancement&template=suggestion.yml">Make a Sugestion</a>
  |
  <a href="https://github.com/starling-cloud/bearing/discussions">Start a Discussion</a>
</div>

<br/>

<div align="center">

[![license](https://img.shields.io/github/license/starling-cloud/bearing?color=green&label=license&style=flat-square)](LICENSE.md)
[![website](https://img.shields.io/website?color=blue&down_color=red&down_message=offline&label=website&style=flat-square&up_color=green&up_message=online&url=https%3A%2F%2Fwww.starling.associates)](https://www.starling.associates)

![stars](https://img.shields.io/github/stars/starling-cloud/bearing?color=blue&label=stars&style=flat-square)
![forks](https://img.shields.io/github/forks/starling-cloud/bearing?color=blue&label=forks&style=flat-square)
![downloads](https://img.shields.io/github/downloads/starling-cloud/bearing/total?color=blue&label=downloads&style=flat-square)
![sponsors](https://img.shields.io/github/sponsors/starling-cloud?color=blue&label=sponsors&style=flat-square)
![contributors](https://img.shields.io/github/contributors/starling-cloud/bearing?color=blue&label=contributors&style=flat-square)

</div>

<br/>

<details open="open">
<summary>Table of Contents</summary>

- [About](#about)
- [Quick Start](#quick-start)
- [Usage](#usage)
- [Authors](#authors)
- [Roadmap](#roadmap)
- [License](#license)
- [Contributing](#contributing)
- [Disclaimer](#disclaimer)

</details>


## About


**Starling Bearing** is a Spatial Python Framework.



## Quick Start

...


## Usage

...



## Authors

**Starling Bearing** is an open-source project by [Starling Associates](https://www.starling.associates "Starling Associates website").

Starling is a spatial insight, strategy and design bureau that develops regenerative and lively environments with a net-positive impact on our future. We embrace the beautiful complexity of our planet’s ecosystems and use a systemic approach to sustainability, circularity and nature-inclusiveness. We go well beyond the life cycle of the places we design and aim to foster the cycle of life that flows through them. Therefore, we develop innovative instruments that are inspired by natural principles and allow us to generate a deep understanding of the environment. We utilise these constantly evolving insights to develop strategies and designs that serve people, society, economy and the ecologies in which they reside in harmony.

website: [www.starling.associates](https://www.starling.associates "Starling Associates website")


## Roadmap


## License

Except where otherwise noted, **Starling Bearing** is licensed under the terms of the [Creative Commons Attribution-ShareAlike 4.0 International License](https://creativecommons.org/licenses/by-sa/4.0/ "Creative Commons Attribution-ShareAlike 4.0 International License").


## Contributing

We'd love for you to contribute and to make **Starling Bearing** even better than it is today!
Please refer to the [contribution guidelines](CONTRIBUTING.md) for information.


## Disclaimer

**THIS SOFTWARE IS PROVIDED AS IS WITHOUT WARRANTY OF ANY KIND, EITHER EXPRESS OR IMPLIED, INCLUDING ANY IMPLIED WARRANTIES OF FITNESS FOR A PARTICULAR PURPOSE, MERCHANTABILITY, OR NON-INFRINGEMENT.**
